/****************************************************************************
** Meta object code from reading C++ file 'ddesktopinputselectioncontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/ddesktopinputselectioncontrol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ddesktopinputselectioncontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22deepin_platform_plugin29DDesktopInputSelectionControlE_t {};
} // unnamed namespace

template <> constexpr inline auto deepin_platform_plugin::DDesktopInputSelectionControl::qt_create_metaobjectdata<qt_meta_tag_ZN22deepin_platform_plugin29DDesktopInputSelectionControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "deepin_platform_plugin::DDesktopInputSelectionControl",
        "anchorPositionChanged",
        "",
        "cursorPositionChanged",
        "anchorRectangleChanged",
        "cursorRectangleChanged",
        "selectionControlVisibleChanged",
        "updateAnchorHandlePosition",
        "updateCursorHandlePosition",
        "updateTooltipPosition",
        "onWindowStateChanged",
        "Qt::WindowState",
        "state",
        "updateSelectionControlVisible",
        "onOptAction",
        "type",
        "onFocusWindowChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'anchorPositionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'anchorRectangleChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorRectangleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionControlVisibleChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAnchorHandlePosition'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateCursorHandlePosition'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTooltipPosition'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onWindowStateChanged'
        QtMocHelpers::SlotData<void(Qt::WindowState)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'updateSelectionControlVisible'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onOptAction'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'onFocusWindowChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DDesktopInputSelectionControl, qt_meta_tag_ZN22deepin_platform_plugin29DDesktopInputSelectionControlE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject deepin_platform_plugin::DDesktopInputSelectionControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22deepin_platform_plugin29DDesktopInputSelectionControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22deepin_platform_plugin29DDesktopInputSelectionControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22deepin_platform_plugin29DDesktopInputSelectionControlE_t>.metaTypes,
    nullptr
} };

void deepin_platform_plugin::DDesktopInputSelectionControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DDesktopInputSelectionControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->anchorPositionChanged(); break;
        case 1: _t->cursorPositionChanged(); break;
        case 2: _t->anchorRectangleChanged(); break;
        case 3: _t->cursorRectangleChanged(); break;
        case 4: _t->selectionControlVisibleChanged(); break;
        case 5: _t->updateAnchorHandlePosition(); break;
        case 6: _t->updateCursorHandlePosition(); break;
        case 7: _t->updateTooltipPosition(); break;
        case 8: _t->onWindowStateChanged((*reinterpret_cast<std::add_pointer_t<Qt::WindowState>>(_a[1]))); break;
        case 9: _t->updateSelectionControlVisible(); break;
        case 10: _t->onOptAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->onFocusWindowChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DDesktopInputSelectionControl::*)()>(_a, &DDesktopInputSelectionControl::anchorPositionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDesktopInputSelectionControl::*)()>(_a, &DDesktopInputSelectionControl::cursorPositionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDesktopInputSelectionControl::*)()>(_a, &DDesktopInputSelectionControl::anchorRectangleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDesktopInputSelectionControl::*)()>(_a, &DDesktopInputSelectionControl::cursorRectangleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDesktopInputSelectionControl::*)()>(_a, &DDesktopInputSelectionControl::selectionControlVisibleChanged, 4))
            return;
    }
}

const QMetaObject *deepin_platform_plugin::DDesktopInputSelectionControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *deepin_platform_plugin::DDesktopInputSelectionControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22deepin_platform_plugin29DDesktopInputSelectionControlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int deepin_platform_plugin::DDesktopInputSelectionControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void deepin_platform_plugin::DDesktopInputSelectionControl::anchorPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void deepin_platform_plugin::DDesktopInputSelectionControl::cursorPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void deepin_platform_plugin::DDesktopInputSelectionControl::anchorRectangleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void deepin_platform_plugin::DDesktopInputSelectionControl::cursorRectangleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void deepin_platform_plugin::DDesktopInputSelectionControl::selectionControlVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
