/****************************************************************************
** Meta object code from reading C++ file 'dplatformwindowhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../dplatformwindowhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dplatformwindowhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22deepin_platform_plugin21DPlatformWindowHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto deepin_platform_plugin::DPlatformWindowHelper::qt_create_metaobjectdata<qt_meta_tag_ZN22deepin_platform_plugin21DPlatformWindowHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "deepin_platform_plugin::DPlatformWindowHelper",
        "updateClipPathFromProperty",
        "",
        "updateFrameMaskFromProperty",
        "updateWindowRadiusFromProperty",
        "updateBorderWidthFromProperty",
        "updateBorderColorFromProperty",
        "updateShadowRadiusFromProperty",
        "updateShadowOffsetFromProperty",
        "updateShadowColorFromProperty",
        "updateEnableSystemResizeFromProperty",
        "updateEnableSystemMoveFromProperty",
        "updateEnableBlurWindowFromProperty",
        "updateWindowBlurAreasFromProperty",
        "updateWindowBlurPathsFromProperty",
        "updateAutoInputMaskByClipPathFromProperty"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updateClipPathFromProperty'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFrameMaskFromProperty'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowRadiusFromProperty'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateBorderWidthFromProperty'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateBorderColorFromProperty'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateShadowRadiusFromProperty'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateShadowOffsetFromProperty'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateShadowColorFromProperty'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateEnableSystemResizeFromProperty'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateEnableSystemMoveFromProperty'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateEnableBlurWindowFromProperty'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowBlurAreasFromProperty'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowBlurPathsFromProperty'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateAutoInputMaskByClipPathFromProperty'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DPlatformWindowHelper, qt_meta_tag_ZN22deepin_platform_plugin21DPlatformWindowHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject deepin_platform_plugin::DPlatformWindowHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22deepin_platform_plugin21DPlatformWindowHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22deepin_platform_plugin21DPlatformWindowHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22deepin_platform_plugin21DPlatformWindowHelperE_t>.metaTypes,
    nullptr
} };

void deepin_platform_plugin::DPlatformWindowHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DPlatformWindowHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateClipPathFromProperty(); break;
        case 1: _t->updateFrameMaskFromProperty(); break;
        case 2: _t->updateWindowRadiusFromProperty(); break;
        case 3: _t->updateBorderWidthFromProperty(); break;
        case 4: _t->updateBorderColorFromProperty(); break;
        case 5: _t->updateShadowRadiusFromProperty(); break;
        case 6: _t->updateShadowOffsetFromProperty(); break;
        case 7: _t->updateShadowColorFromProperty(); break;
        case 8: _t->updateEnableSystemResizeFromProperty(); break;
        case 9: _t->updateEnableSystemMoveFromProperty(); break;
        case 10: _t->updateEnableBlurWindowFromProperty(); break;
        case 11: _t->updateWindowBlurAreasFromProperty(); break;
        case 12: _t->updateWindowBlurPathsFromProperty(); break;
        case 13: _t->updateAutoInputMaskByClipPathFromProperty(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *deepin_platform_plugin::DPlatformWindowHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *deepin_platform_plugin::DPlatformWindowHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22deepin_platform_plugin21DPlatformWindowHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int deepin_platform_plugin::DPlatformWindowHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
